==> customer-link-project-api-0.0.99-20230506.063518-3-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app92580/dto/SendTemplateMessageDTO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app92580.dto;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class SendTemplateMessageDTO {

    /**
     * 小程序wpaId
     */
    private String wpaId;

    /**
     * 小程序授权的openId
     */
    private String touser;

    /**
     * async-异步, sync-同步
     */
    private String sendType;

    /**
     * 模板发送时间[async-异步时必填], 格式: yyyy-MM-dd HH:mm:ss
     */
    private String sendTime;

    private MpTemplateMsg mpTemplateMsg;

    public String getWpaId() {
        return wpaId;
    }

    public void setWpaId(String wpaId) {
        this.wpaId = wpaId;
    }

    public String getTouser() {
        return touser;
    }

    public void setTouser(String touser) {
        this.touser = touser;
    }

    public String getSendType() {
        return sendType;
    }

    public void setSendType(String sendType) {
        this.sendType = sendType;
    }

    public String getSendTime() {
        return sendTime;
    }

    public void setSendTime(String sendTime) {
        this.sendTime = sendTime;
    }

    public MpTemplateMsg getMpTemplateMsg() {
        return mpTemplateMsg;
    }

    public void setMpTemplateMsg(MpTemplateMsg mpTemplateMsg) {
        this.mpTemplateMsg = mpTemplateMsg;
    }

    public static class MpTemplateMsg {
        private Data data;
        /**
         * 本地模板ID
         */
        private String templateId;

        private Miniprogram miniprogram;
        private String url;

        public Data getData() {
            return data;
        }

        public void setData(Data data) {
            this.data = data;
        }

        public String getTemplateId() {
            return templateId;
        }

        public void setTemplateId(String templateId) {
            this.templateId = templateId;
        }

        public Miniprogram getMiniprogram() {
            return miniprogram;
        }

        public void setMiniprogram(Miniprogram miniprogram) {
            this.miniprogram = miniprogram;
        }

        public String getUrl() {
            return url;
        }

        public void setUrl(String url) {
            this.url = url;
        }
    }

    public static class Data {

        private Content remark;
        private Content first;
        private Content keyword1;
        private Content keyword2;
        private Content keyword3;

        public Content getRemark() {
            return remark;
        }

        public void setRemark(Content remark) {
            this.remark = remark;
        }

        public Content getFirst() {
            return first;
        }

        public void setFirst(Content first) {
            this.first = first;
        }

        public Content getKeyword1() {
            return keyword1;
        }

        public void setKeyword1(Content keyword1) {
            this.keyword1 = keyword1;
        }

        public Content getKeyword2() {
            return keyword2;
        }

        public void setKeyword2(Content keyword2) {
            this.keyword2 = keyword2;
        }

        public Content getKeyword3() {
            return keyword3;
        }

        public void setKeyword3(Content keyword3) {
            this.keyword3 = keyword3;
        }
    }

    public static class Content {

        private String color;

        private String value;

        public String getColor() {
            return color;
        }

        public void setColor(String color) {
            this.color = color;
        }

        public String getValue() {
            return value;
        }

        public void setValue(String value) {
            this.value = value;
        }
    }

    public static class Miniprogram {
        /**
         * 页面跳转地址
         */
        private String pagepath;

        /**
         * 小程序appid
         */
        private String appid;

        public String getPagepath() {
            return pagepath;
        }

        public void setPagepath(String pagepath) {
            this.pagepath = pagepath;
        }

        public String getAppid() {
            return appid;
        }

        public void setAppid(String appid) {
            this.appid = appid;
        }
    }
}

==> customer-link-project-api-1.1.25-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app92580/dto/SendTemplateMessageDTO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app92580.dto;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class SendTemplateMessageDTO {

    /**
     * 小程序wpaId
     */
    private String wpaId;

    /**
     * 小程序授权的openId
     */
    private String touser;

    /**
     * async-异步, sync-同步
     */
    private String sendType;

    /**
     * 模板发送时间[async-异步时必填], 格式: yyyy-MM-dd HH:mm:ss
     */
    private String sendTime;

    private MpTemplateMsg mpTemplateMsg;

    /**
     * 模板可发送开始时间
     */
    private String startTime;

    /**
     * 模板可发送结束时间
     */
    private String endTime;

    public String getWpaId() {
        return wpaId;
    }

    public void setWpaId(String wpaId) {
        this.wpaId = wpaId;
    }

    public String getTouser() {
        return touser;
    }

    public void setTouser(String touser) {
        this.touser = touser;
    }

    public String getSendType() {
        return sendType;
    }

    public void setSendType(String sendType) {
        this.sendType = sendType;
    }

    public String getSendTime() {
        return sendTime;
    }

    public void setSendTime(String sendTime) {
        this.sendTime = sendTime;
    }

    public MpTemplateMsg getMpTemplateMsg() {
        return mpTemplateMsg;
    }

    public void setMpTemplateMsg(MpTemplateMsg mpTemplateMsg) {
        this.mpTemplateMsg = mpTemplateMsg;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public static class MpTemplateMsg {
        private Data data;
        /**
         * 本地模板ID
         */
        private String templateId;

        private Miniprogram miniprogram;
        private String url;

        public Data getData() {
            return data;
        }

        public void setData(Data data) {
            this.data = data;
        }

        public String getTemplateId() {
            return templateId;
        }

        public void setTemplateId(String templateId) {
            this.templateId = templateId;
        }

        public Miniprogram getMiniprogram() {
            return miniprogram;
        }

        public void setMiniprogram(Miniprogram miniprogram) {
            this.miniprogram = miniprogram;
        }

        public String getUrl() {
            return url;
        }

        public void setUrl(String url) {
            this.url = url;
        }
    }

    public static class Data {

        private Content remark;
        private Content first;
        private Content keyword1;
        private Content keyword2;
        private Content keyword3;

        public Content getRemark() {
            return remark;
        }

        public void setRemark(Content remark) {
            this.remark = remark;
        }

        public Content getFirst() {
            return first;
        }

        public void setFirst(Content first) {
            this.first = first;
        }

        public Content getKeyword1() {
            return keyword1;
        }

        public void setKeyword1(Content keyword1) {
            this.keyword1 = keyword1;
        }

        public Content getKeyword2() {
            return keyword2;
        }

        public void setKeyword2(Content keyword2) {
            this.keyword2 = keyword2;
        }

        public Content getKeyword3() {
            return keyword3;
        }

        public void setKeyword3(Content keyword3) {
            this.keyword3 = keyword3;
        }
    }

    public static class Content {

        private String color;

        private String value;

        public String getColor() {
            return color;
        }

        public void setColor(String color) {
            this.color = color;
        }

        public String getValue() {
            return value;
        }

        public void setValue(String value) {
            this.value = value;
        }
    }

    public static class Miniprogram {
        /**
         * 页面跳转地址
         */
        private String pagepath;

        /**
         * 小程序appid
         */
        private String appid;

        public String getPagepath() {
            return pagepath;
        }

        public void setPagepath(String pagepath) {
            this.pagepath = pagepath;
        }

        public String getAppid() {
            return appid;
        }

        public void setAppid(String appid) {
            this.appid = appid;
        }
    }


}
